datahandler(python)

Handling Missing values in a given data set and imputing them in python.

Install this library using pip in cmd/powershell (ADMIN) ----> pip install datahandler-bhanu

Comes with command line support. Use directly from cmd/powershell by typing python filename.py datafilename.csv and wallah!
Github Link -> https://github.com/eternaldemon/datahandler
PyPi Link -> https://pypi.org/project/datahandler-bhanu/

Libraries Used --> Pandas,sklearn,sys,numpy

You can import it directly using import datahandler and use the function datahandler as datahandler.datahandler The updated data will be exported to a new file called data_new.csv